package tech.nevets.vcardgen;

import com.google.gson.Gson;
import com.google.gson.JsonObject;

import javax.servlet.MultipartConfigElement;
import java.io.*;

import static spark.Spark.*;

public class Main {
    public static void main(String[] args) {
        Location.loadLocations();

        port(8080);
        path("/backend", () -> {
            before("/*", (request, response) -> response.header("Access-Control-Allow-Origin", "*"));

            options("/*", (request, response) -> {
                String accessControlRequestHeaders = request.headers("Access-Control-Request-Headers");
                if (accessControlRequestHeaders != null) response.header("Access-Control-Allow-Headers", accessControlRequestHeaders);

                String accessControlRequestMethod = request.headers("Access-Control-Request-Method");
                if (accessControlRequestMethod != null) response.header("Access-Control-Allow-Methods", accessControlRequestMethod);

                return "OK";
            });


            get("/heartbeat", (req, res) -> {
                res.status(200);
                res.type("application/json");
                return "{ \"up\":true }";
            });

            get("/data/locations", (req, res) -> {
                res.status(200);
                res.type("application/json");
                return new FileInputStream("locations.json");
            });

            post("/generate", (req, res) -> {
                res.type("image/png");
                res.header("Access-Control-Expose-Headers", "Id");
                JsonObject data = new Gson().fromJson(req.body(), JsonObject.class);
                return new VCard(data).toByteArray();
            });

            post("/edit", (req, res) -> {
                req.attribute("org.eclipse.jetty.multipartConfig", new MultipartConfigElement("/temp"));
                res.status(200);
                res.type("application/json");
                return VCard.getDataFromVCard(req.raw().getPart("card").getInputStream());
            });
        });
    }
}
